@@ -1,3 +1,29 @@
+/*
+
+g3data : A program for grabbing data from scanned graphs
+Copyright (C) 2000 Jonas Frantz
+
+    This file is part of g3data.
+
+    g3data is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    g3data is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+Authors email : jonas.frantz@welho.com
+
+*/
+
 /************************************************************************************************/
 /* 					ABOUT INFO 						*/
 /************************************************************************************************/
@@ -6,7 +32,7 @@
 #define COPYRIGHT "Copyright (C) 2000 Jonas Frantz"
 #define COMMENTS "Grab graph data, a program for extracting data from graphs"
 #define LICENSE "g3data is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n\ng3data is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
-#define HOMEPAGEURL "http://koti.welho.com/jfrantz/software/g3data.html"
+#define HOMEPAGEURL "http://www.frantz.fi/software/g3data.php"
 #define HOMEPAGELABEL "g3data homepage"
 #define AUTHORS {"Jonas Frantz", NULL}
 
